@@ -40,7 +40,11 @@ class CirclePermissions(LDPPermissions):
 
             # model-level permissions
             else:
-                perms = perms.union({'view', 'add'})
+                default_perms = getattr(settings, 'USER_AUTHENTICATED_CIRCLE_PERMISSIONS', ['view', 'add'])
+                perms = perms.union(set(default_perms))
+                # a superuser can always add new circles
+                if user.is_superuser:
+                    perms = perms.union({'add'})
 
         return list(perms)
     
