@@ -37,6 +37,13 @@ class CirclesJoinableViewset(LDPViewSet):
 
     filter_backends = [LocalObjectFilterBackend]
 
+    def __init__(self, **kwargs):
+        from djangoldp_circle.models import Circle
+
+        kwargs['model'] = Circle
+        kwargs['nested_fields'] = Circle.nested.fields()
+        super().__init__(**kwargs)
+
     def get_queryset(self):
         return super().get_queryset().exclude(members__user=self.request.user.id)\
             .exclude(status="Private")\
